=== modified file 'bzrlib/plugins/weave_fmt/workingtree.py'
--- bzrlib/plugins/weave_fmt/workingtree.py	2011-05-20 10:51:09 +0000
+++ bzrlib/plugins/weave_fmt/workingtree.py	2011-06-28 11:29:03 +0000
@@ -55,6 +55,8 @@
 
     missing_parent_conflicts = False
 
+    supports_versioned_directories = True
+
     def get_format_description(self):
         """See WorkingTreeFormat.get_format_description()."""
         return "Working tree format 2"

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2011-06-18 13:57:17 +0000
+++ bzrlib/repository.py	2011-06-28 11:42:02 +0000
@@ -1409,6 +1409,8 @@
     revision_graph_can_have_wrong_parents = None
     # Does this format support rich root data?
     rich_root_data = None
+    # Does this format support explicitly versioned directories?
+    supports_versioned_directories = None
 
     def __repr__(self):
         return "%s()" % self.__class__.__name__

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2011-05-14 21:16:04 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-06-28 11:42:02 +0000
@@ -90,6 +90,9 @@
         self.assertFormatAttribute('supports_leaving_lock',
             (True, False))
 
+    def test_attribute_format_versioned_directories(self):
+        self.assertFormatAttribute('supports_versioned_directories', (True, False))
+
     def test_attribute_format_revision_graph_can_have_wrong_parents(self):
         self.assertFormatAttribute('revision_graph_can_have_wrong_parents',
             (True, False))

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2011-06-28 11:29:03 +0000
@@ -1159,3 +1159,11 @@
         # If the config entry is invalid, default to 10
         # TODO: This writes a warning to the user, trap it somehow
         self.assertEqual(10, wt._worth_saving_limit())
+
+
+class TestFormatAttributes(TestCaseWithWorkingTree):
+
+    def test_versioned_directories(self):
+        self.assertSubset(
+            [self.workingtree_format.supports_versioned_directories],
+            (True, False))

=== modified file 'bzrlib/vf_repository.py'
--- bzrlib/vf_repository.py	2011-05-20 13:28:35 +0000
+++ bzrlib/vf_repository.py	2011-06-28 11:42:02 +0000
@@ -78,6 +78,7 @@
     """Base class for all repository formats that are VersionedFiles-based."""
 
     supports_full_versioned_files = True
+    supports_versioned_directories = True
 
     # Should commit add an inventory, or an inventory delta to the repository.
     _commit_inv_deltas = True

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2011-06-18 13:57:17 +0000
+++ bzrlib/workingtree.py	2011-06-28 11:29:03 +0000
@@ -3016,6 +3016,8 @@
     missing_parent_conflicts = False
     """If this format supports missing parent conflicts."""
 
+    supports_versioned_directories = None
+
     @classmethod
     def find_format_string(klass, a_bzrdir):
         """Return format name for the working tree object in a_bzrdir."""

=== modified file 'bzrlib/workingtree_3.py'
--- bzrlib/workingtree_3.py	2011-05-20 10:49:09 +0000
+++ bzrlib/workingtree_3.py	2011-06-28 11:29:03 +0000
@@ -102,6 +102,8 @@
 
     missing_parent_conflicts = True
 
+    supports_versioned_directories = True
+
     def get_format_string(self):
         """See WorkingTreeFormat.get_format_string()."""
         return "Bazaar-NG Working Tree format 3"

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2011-06-16 11:58:04 +0000
+++ bzrlib/workingtree_4.py	2011-06-28 11:29:03 +0000
@@ -1462,6 +1462,8 @@
 
     missing_parent_conflicts = True
 
+    supports_versioned_directories = True
+
     _lock_class = LockDir
     _lock_file_name = 'lock'
 

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2011-06-28 15:58:20 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2011-06-28 16:41:23 +0000
@@ -59,6 +59,10 @@
 .. Changes that may require updates in plugins or other code that uses
    bzrlib.
 
+* New attributes ``WorkingTreeFormat.supports_versioned_directories`` and
+  ``RepositoryFormat.supports_versioned_directories``.
+  (Jelmer Vernooij, #765815)
+
 Internals
 *********
 

